@@ -75,7 +75,7 @@ def makeIndividualData(file,tags):
             pass
 
     df['Tag'] = df['Tag'].fillna('undefined')
-    for i, tagValue in tags:
+    for i, tagValue in enumerate(tags):
         df.loc[df['Tag'] == tagValue, 'num_labels'] = i+1
 
     assert df[
