@@ -56,12 +56,14 @@ class Grapher:
         """
         preprocessing the raw csv files to favorable df 
         """
-        df = df[0].str.split(',', expand=True)
+        df = pd.DataFrame([node.getInfo() for node in self.nodes])
+        """
+        preprocessing the raw csv files to favorable df 
+        """
+
         temp = df.copy()
-        temp[temp.columns] = temp.apply(lambda x: x.str.strip())
         temp.fillna('', inplace=True)
-        temp.columns = ['xmin', 'ymin', 'xmax', 'ymax', 'Object','Tag']
-        temp[['xmin', 'ymin', 'xmax', 'ymax']] = temp[['xmin', 'ymin', 'xmax', 'ymax']].apply(pd.to_numeric)
+        temp.columns = ['xmin', 'ymin', 'xmax', 'ymax', 'Object', 'Tag']
         df = temp
 
         assert type(df) == pd.DataFrame, f'object_map should be of type \
