@@ -7,7 +7,10 @@ class Node:
         self.Object = Object
         self.Tag = Tag
 
-    def to_string(self):
-        return ','.join([str(self.XMin), str(self.YMin), str(self.XMax), str(self.YMax),self.Object, self.Tag])
+
+    def getInfo(self):
+        return [self.XMin, self.YMin, self.XMax, self.YMax, self.Object, self.Tag]
+
+
 
 
